landinggear
===========

``landinggear`` was born out of the complaints of some friends who travel a lot
and like to write software while on aeroplanes.

usage
-----

Use ``landinggear path/to/wheelhouse`` to populate your wheelhouse from your
pip cache. Then use ``pip install --no-index -f path/to/wheelhouse mypackage``
to install packages.


TODO
----

Figure out how to write some more useful tests.
